pub struct Font { /* private fields */ }Expand description
A font that contains the printpdf object font needed to render text and the freetype font needed to measure text.
Implementations
Sourceimpl Font
impl Font
Sourcepub fn from_file<P: AsRef<Path>>(
path: P,
library: &Library,
document: &mut Document,
) -> Result<Font>
pub fn from_file<P: AsRef<Path>>( path: P, library: &Library, document: &mut Document, ) -> Result<Font>
Creates a font from a path to a file.
Sourcepub fn from_bytes(
bytes: &[u8],
library: &Library,
document: &mut Document,
) -> Result<Font>
pub fn from_bytes( bytes: &[u8], library: &Library, document: &mut Document, ) -> Result<Font>
Creates a font from a byte array.
Sourcepub fn char_width(&self, c: char, scale: Pt) -> Pt
pub fn char_width(&self, c: char, scale: Pt) -> Pt
Computes the width of a char of the font at a specified size.
Sourcepub fn text_width(&self, text: &str, scale: Pt) -> Pt
pub fn text_width(&self, text: &str, scale: Pt) -> Pt
Computes the text width of the font at a specified size.
Sourcepub fn printpdf(&self) -> &IndirectFontRef
pub fn printpdf(&self) -> &IndirectFontRef
Returns a reference to the printpdf font.